@@ -20,6 +20,7 @@ class DataStageUpdateMonitorStateRequestSchema(ApiStrictSchema):
 @attr.s
 class DataStageServerConfig(BaseServerConfig):
     project_id = attr.ib(default=None)  # type: str
+    project_ids = attr.ib(factory=list)
     api_key = attr.ib(default=None)  # type: str
     runs_bulk_size = attr.ib(default=10)  # type: int
     page_size = attr.ib(default=200)  # type: int
@@ -28,13 +29,14 @@ class DataStageServerConfig(BaseServerConfig):
     datastage_runs_syncer_enabled = attr.ib(default=True)  # type: bool
     host_name = attr.ib(default=None)  # type: str
     authentication_provider_url = attr.ib(default=None)  # type: str
+    log_level = attr.ib(default=None)  # type: str
 
     @classmethod
     def create(
         cls, server_config: dict, monitor_config: Optional[BaseMonitorConfig] = None
     ):
         monitor_instance_config = server_config.get("monitor_config") or {}
-
+        project_id = server_config["project_id"]
         conf = cls(
             source_type="datastage",
             source_name=server_config["source_name"],
@@ -48,7 +50,8 @@ class DataStageServerConfig(BaseServerConfig):
             number_of_fetching_threads=monitor_instance_config[
                 "number_of_fetching_threads"
             ],
-            project_id=server_config["project_id"],
+            project_id=project_id,
+            project_ids=server_config.get("project_ids", [project_id]),
             api_key=server_config["api_key"],
             host_name=server_config["host_name"],
             authentication_provider_url=server_config["authentication_provider_url"],
@@ -56,6 +59,7 @@ class DataStageServerConfig(BaseServerConfig):
             datastage_runs_syncer_enabled=monitor_instance_config[
                 "datastage_runs_syncer_enabled"
             ],
+            log_level=monitor_instance_config.get("log_level"),
         )
         return conf
 
